Base classes (mid level)
=========================

This module provides abstract base classes for building probabilistic models at the mid level.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Base Constructor Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   BaseConstructor


Class Documentation
-------------------

.. autoclass:: BaseConstructor
   :members:
   :undoc-members:
   :show-inheritance:
